California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance Activity Propositions & Ballot Measures
Election Cycle: 2021 through 2022 Historical 2019 through 2020 2017 through 2018 2015 through 2016 2013 through 2014 2011 through 2012 2009 through 2010 2007 through 2008 2005 through 2006 2003 through 2004 2001 through 2002 1999 through 2000
All of the campaign committees that have organized to support or oppose propositions and ballot measures on California's statewide ballot are available here. Click below on the proposition or ballot measure to learn who is involved in the campaign to win your vote on Election Day.
Prior Elections
NOVEMBER 4, 2014, GENERAL
6 Measures
PROPOSITION 001 - AB 1471 WATER QUALITY, SUPPLY AND INFRASTRUCTURE IMPROVEMENT ACT OF 2014
PROPOSITION 002 - STATE RESERVE POLICY.
PROPOSITION 045 - APPROVAL OF HEALTHCARE INSURANCE RATE CHANGES. INITIATIVE STATUTE.
PROPOSITION 046 - DRUG AND ALCOHOL TESTING OF DOCTORS. MEDICAL NEGLIGENCE LAWSUITS. INITIATIVE STATUTE.
PROPOSITION 047 - CRIMINAL SENTENCES. MISDEMEANOR PENALTIES. INITIATIVE STATUTE.
PROPOSITION 048 - REFERENDUM TO OVERTURN INDIAN GAMING COMPACTS.
JUNE 3, 2014, PRIMARY
2 Measures
PROPOSITION 041 - VETERANS HOUSING AND HOMELESS PREVENTION BOND ACT OF 2014
PROPOSITION 042 - PUBLIC INFORMATION. OPEN MEETINGS. STATE REIMBURSEMENT TO LOCAL AGENCIES. LEGISLATIVE CONSTITUTIONAL AMENDMENT.